This will update the following files:

 drivers/scsi/sata_promise.c

through these ChangeSets:

  o [libata sata_promise] support PATA ports on SATA controllers

patches provided by Jim Bevier jbev@jbsys.com

diff -Nru a/drivers/scsi/sata_promise.c b/drivers/scsi/sata_promise.c
--- a/drivers/ata/sata_promise.c	2006-12-27 12:32:27.000000000 -0700
+++ b/drivers/ata/sata_promise.c	2007-01-12 16:11:44.000000000 -0700
@@ -92,6 +92,7 @@
 
 struct pdc_host_priv {
 	unsigned long		flags;
+	unsigned long		port_flags[ATA_MAX_PORTS];	/* pata fix */
 };
 
 static u32 pdc_sata_scr_read (struct ata_port *ap, unsigned int sc_reg);
@@ -183,7 +183,7 @@
 	/* board_2037x */
 	{
 		.sht		= &pdc_ata_sht,
-		.flags		= PDC_COMMON_FLAGS | ATA_FLAG_SATA,
+		.flags		= PDC_COMMON_FLAGS /* | ATA_FLAG_SATA */,	/* pata fix */
 		.pio_mask	= 0x1f, /* pio0-4 */
 		.mwdma_mask	= 0x07, /* mwdma0-2 */
 		.udma_mask	= 0x7f, /* udma0-6 ; FIXME */
@@ -213,7 +213,7 @@
 	/* board_2057x */
 	{
 		.sht		= &pdc_ata_sht,
-		.flags		= PDC_COMMON_FLAGS | ATA_FLAG_SATA,
+		.flags		= PDC_COMMON_FLAGS /* | ATA_FLAG_SATA */,	/* pata fix */
 		.pio_mask	= 0x1f, /* pio0-4 */
 		.mwdma_mask	= 0x07, /* mwdma0-2 */
 		.udma_mask	= 0x7f, /* udma0-6 ; FIXME */
@@ -271,6 +272,11 @@
 	struct pdc_port_priv *pp;
 	int rc;
 
+	/* fix up port flags and cable type for SATA+PATA chips */	/* pata fix */
+	ap->flags |= hp->port_flags[ap->port_no];			/* pata fix */
+	if (ap->flags & ATA_FLAG_SATA)					/* pata fix */
+		ap->cbl = ATA_CBL_SATA;					/* pata fix */
+									/* pata fix */
 	rc = ata_port_start(ap);
 	if (rc)
 		return rc;
@@ -377,7 +383,8 @@
 
 static u32 pdc_sata_scr_read (struct ata_port *ap, unsigned int sc_reg)
 {
-	if (sc_reg > SCR_CONTROL)
+/*	if (sc_reg > SCR_CONTROL) */				/* pata fix */
+	if (sc_reg > SCR_CONTROL || ap->cbl != ATA_CBL_SATA)	/* pata fix */
 		return 0xffffffffU;
 	return readl((void __iomem *) ap->ioaddr.scr_addr + (sc_reg * 4));
 }
@@ -386,7 +393,8 @@
 static void pdc_sata_scr_write (struct ata_port *ap, unsigned int sc_reg,
 			       u32 val)
 {
-	if (sc_reg > SCR_CONTROL)
+/*	if (sc_reg > SCR_CONTROL) */				/* pata fix */
+	if (sc_reg > SCR_CONTROL || ap->cbl != ATA_CBL_SATA)	/* pata fix */
 		return;
 	writel(val, (void __iomem *) ap->ioaddr.scr_addr + (sc_reg * 4));
 }
@@ -740,6 +748,7 @@
 	unsigned int board_idx = (unsigned int) ent->driver_data;
 	int pci_dev_busy = 0;
 	int rc;
+	u8 tmp;		/* pata fix */
 
 	if (!printed_version++)
 		dev_printk(KERN_DEBUG, &pdev->dev, "version " DRV_VERSION "\n");
@@ -821,6 +830,17 @@
 		/* Fall through */
 	case board_2037x:
 		probe_ent->n_ports = 2;
+		/* TX2plus boards also have a PATA port */	/* pata fix */
+		tmp = readb(mmio_base + PDC_FLASH_CTL+1);	/* pata fix */
+		if (!(tmp & 0x80))				/* pata fix */
+		{						/* pata fix */
+			probe_ent->n_ports = 3;			/* pata fix */
+			pdc_ata_setup_port(&probe_ent->port[2], base + 0x300);	/* pata fix */
+			hp->port_flags[2] = ATA_FLAG_SLAVE_POSS;		/* pata fix */
+			printk(KERN_INFO DRV_NAME " PATA port found\n");	/* pata fix */
+		}						/* pata fix */
+		hp->port_flags[0] = ATA_FLAG_SATA;		/* pata fix */
+		hp->port_flags[1] = ATA_FLAG_SATA;		/* pata fix */
 		break;
 	case board_20619:
 		probe_ent->n_ports = 4;
